# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: google/ads/googleads_v2/proto/enums/feed_mapping_status.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='google/ads/googleads_v2/proto/enums/feed_mapping_status.proto',
  package='google.ads.googleads.v2.enums',
  syntax='proto3',
  serialized_options=_b('\n!com.google.ads.googleads.v2.enumsB\026FeedMappingStatusProtoP\001ZBgoogle.golang.org/genproto/googleapis/ads/googleads/v2/enums;enums\242\002\003GAA\252\002\035Google.Ads.GoogleAds.V2.Enums\312\002\035Google\\Ads\\GoogleAds\\V2\\Enums\352\002!Google::Ads::GoogleAds::V2::Enums'),
  serialized_pb=_b('\n=google/ads/googleads_v2/proto/enums/feed_mapping_status.proto\x12\x1dgoogle.ads.googleads.v2.enums\x1a\x1cgoogle/api/annotations.proto\"d\n\x15\x46\x65\x65\x64MappingStatusEnum\"K\n\x11\x46\x65\x65\x64MappingStatus\x12\x0f\n\x0bUNSPECIFIED\x10\x00\x12\x0b\n\x07UNKNOWN\x10\x01\x12\x0b\n\x07\x45NABLED\x10\x02\x12\x0b\n\x07REMOVED\x10\x03\x42\xeb\x01\n!com.google.ads.googleads.v2.enumsB\x16\x46\x65\x65\x64MappingStatusProtoP\x01ZBgoogle.golang.org/genproto/googleapis/ads/googleads/v2/enums;enums\xa2\x02\x03GAA\xaa\x02\x1dGoogle.Ads.GoogleAds.V2.Enums\xca\x02\x1dGoogle\\Ads\\GoogleAds\\V2\\Enums\xea\x02!Google::Ads::GoogleAds::V2::Enumsb\x06proto3')
  ,
  dependencies=[google_dot_api_dot_annotations__pb2.DESCRIPTOR,])



_FEEDMAPPINGSTATUSENUM_FEEDMAPPINGSTATUS = _descriptor.EnumDescriptor(
  name='FeedMappingStatus',
  full_name='google.ads.googleads.v2.enums.FeedMappingStatusEnum.FeedMappingStatus',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='UNSPECIFIED', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='UNKNOWN', index=1, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ENABLED', index=2, number=2,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='REMOVED', index=3, number=3,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=151,
  serialized_end=226,
)
_sym_db.RegisterEnumDescriptor(_FEEDMAPPINGSTATUSENUM_FEEDMAPPINGSTATUS)


_FEEDMAPPINGSTATUSENUM = _descriptor.Descriptor(
  name='FeedMappingStatusEnum',
  full_name='google.ads.googleads.v2.enums.FeedMappingStatusEnum',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _FEEDMAPPINGSTATUSENUM_FEEDMAPPINGSTATUS,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=126,
  serialized_end=226,
)

_FEEDMAPPINGSTATUSENUM_FEEDMAPPINGSTATUS.containing_type = _FEEDMAPPINGSTATUSENUM
DESCRIPTOR.message_types_by_name['FeedMappingStatusEnum'] = _FEEDMAPPINGSTATUSENUM
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

FeedMappingStatusEnum = _reflection.GeneratedProtocolMessageType('FeedMappingStatusEnum', (_message.Message,), dict(
  DESCRIPTOR = _FEEDMAPPINGSTATUSENUM,
  __module__ = 'google.ads.googleads_v2.proto.enums.feed_mapping_status_pb2'
  ,
  __doc__ = """Container for enum describing possible statuses of a feed mapping.
  """,
  # @@protoc_insertion_point(class_scope:google.ads.googleads.v2.enums.FeedMappingStatusEnum)
  ))
_sym_db.RegisterMessage(FeedMappingStatusEnum)


DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
import grpc

from google.ads.google_ads.v1.proto.resources import campaign_pb2 as google_dot_ads_dot_googleads__v1_dot_proto_dot_resources_dot_campaign__pb2
from google.ads.google_ads.v1.proto.services import campaign_service_pb2 as google_dot_ads_dot_googleads__v1_dot_proto_dot_services_dot_campaign__service__pb2


class CampaignServiceStub(object):
  """Proto file describing the Campaign service.

  Service to manage campaigns.
  """

  def __init__(self, channel):
    """Constructor.

    Args:
      channel: A grpc.Channel.
    """
    self.GetCampaign = channel.unary_unary(
        '/google.ads.googleads.v1.services.CampaignService/GetCampaign',
        request_serializer=google_dot_ads_dot_googleads__v1_dot_proto_dot_services_dot_campaign__service__pb2.GetCampaignRequest.SerializeToString,
        response_deserializer=google_dot_ads_dot_googleads__v1_dot_proto_dot_resources_dot_campaign__pb2.Campaign.FromString,
        )
    self.MutateCampaigns = channel.unary_unary(
        '/google.ads.googleads.v1.services.CampaignService/MutateCampaigns',
        request_serializer=google_dot_ads_dot_googleads__v1_dot_proto_dot_services_dot_campaign__service__pb2.MutateCampaignsRequest.SerializeToString,
        response_deserializer=google_dot_ads_dot_googleads__v1_dot_proto_dot_services_dot_campaign__service__pb2.MutateCampaignsResponse.FromString,
        )


class CampaignServiceServicer(object):
  """Proto file describing the Campaign service.

  Service to manage campaigns.
  """

  def GetCampaign(self, request, context):
    """Returns the requested campaign in full detail.
    """
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def MutateCampaigns(self, request, context):
    """Creates, updates, or removes campaigns. Operation statuses are returned.
    """
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')


def add_CampaignServiceServicer_to_server(servicer, server):
  rpc_method_handlers = {
      'GetCampaign': grpc.unary_unary_rpc_method_handler(
          servicer.GetCampaign,
          request_deserializer=google_dot_ads_dot_googleads__v1_dot_proto_dot_services_dot_campaign__service__pb2.GetCampaignRequest.FromString,
          response_serializer=google_dot_ads_dot_googleads__v1_dot_proto_dot_resources_dot_campaign__pb2.Campaign.SerializeToString,
      ),
      'MutateCampaigns': grpc.unary_unary_rpc_method_handler(
          servicer.MutateCampaigns,
          request_deserializer=google_dot_ads_dot_googleads__v1_dot_proto_dot_services_dot_campaign__service__pb2.MutateCampaignsRequest.FromString,
          response_serializer=google_dot_ads_dot_googleads__v1_dot_proto_dot_services_dot_campaign__service__pb2.MutateCampaignsResponse.SerializeToString,
      ),
  }
  generic_handler = grpc.method_handlers_generic_handler(
      'google.ads.googleads.v1.services.CampaignService', rpc_method_handlers)
  server.add_generic_rpc_handlers((generic_handler,))



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: google/ads/googleads_v2/proto/resources/geographic_view.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.ads.google_ads.v2.proto.enums import geo_targeting_type_pb2 as google_dot_ads_dot_googleads__v2_dot_proto_dot_enums_dot_geo__targeting__type__pb2
from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2
from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='google/ads/googleads_v2/proto/resources/geographic_view.proto',
  package='google.ads.googleads.v2.resources',
  syntax='proto3',
  serialized_options=_b('\n%com.google.ads.googleads.v2.resourcesB\023GeographicViewProtoP\001ZJgoogle.golang.org/genproto/googleapis/ads/googleads/v2/resources;resources\242\002\003GAA\252\002!Google.Ads.GoogleAds.V2.Resources\312\002!Google\\Ads\\GoogleAds\\V2\\Resources\352\002%Google::Ads::GoogleAds::V2::Resources'),
  serialized_pb=_b('\n=google/ads/googleads_v2/proto/resources/geographic_view.proto\x12!google.ads.googleads.v2.resources\x1a<google/ads/googleads_v2/proto/enums/geo_targeting_type.proto\x1a\x1egoogle/protobuf/wrappers.proto\x1a\x1cgoogle/api/annotations.proto\"\xbf\x01\n\x0eGeographicView\x12\x15\n\rresource_name\x18\x01 \x01(\t\x12[\n\rlocation_type\x18\x03 \x01(\x0e\x32\x44.google.ads.googleads.v2.enums.GeoTargetingTypeEnum.GeoTargetingType\x12\x39\n\x14\x63ountry_criterion_id\x18\x04 \x01(\x0b\x32\x1b.google.protobuf.Int64ValueB\x80\x02\n%com.google.ads.googleads.v2.resourcesB\x13GeographicViewProtoP\x01ZJgoogle.golang.org/genproto/googleapis/ads/googleads/v2/resources;resources\xa2\x02\x03GAA\xaa\x02!Google.Ads.GoogleAds.V2.Resources\xca\x02!Google\\Ads\\GoogleAds\\V2\\Resources\xea\x02%Google::Ads::GoogleAds::V2::Resourcesb\x06proto3')
  ,
  dependencies=[google_dot_ads_dot_googleads__v2_dot_proto_dot_enums_dot_geo__targeting__type__pb2.DESCRIPTOR,google_dot_protobuf_dot_wrappers__pb2.DESCRIPTOR,google_dot_api_dot_annotations__pb2.DESCRIPTOR,])




_GEOGRAPHICVIEW = _descriptor.Descriptor(
  name='GeographicView',
  full_name='google.ads.googleads.v2.resources.GeographicView',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='resource_name', full_name='google.ads.googleads.v2.resources.GeographicView.resource_name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='location_type', full_name='google.ads.googleads.v2.resources.GeographicView.location_type', index=1,
      number=3, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='country_criterion_id', full_name='google.ads.googleads.v2.resources.GeographicView.country_criterion_id', index=2,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=225,
  serialized_end=416,
)

_GEOGRAPHICVIEW.fields_by_name['location_type'].enum_type = google_dot_ads_dot_googleads__v2_dot_proto_dot_enums_dot_geo__targeting__type__pb2._GEOTARGETINGTYPEENUM_GEOTARGETINGTYPE
_GEOGRAPHICVIEW.fields_by_name['country_criterion_id'].message_type = google_dot_protobuf_dot_wrappers__pb2._INT64VALUE
DESCRIPTOR.message_types_by_name['GeographicView'] = _GEOGRAPHICVIEW
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

GeographicView = _reflection.GeneratedProtocolMessageType('GeographicView', (_message.Message,), dict(
  DESCRIPTOR = _GEOGRAPHICVIEW,
  __module__ = 'google.ads.googleads_v2.proto.resources.geographic_view_pb2'
  ,
  __doc__ = """A geographic view.
  
  Geographic View includes all metrics aggregated at the country level,
  one row per country. It reports metrics at either actual physical
  location of the user or an area of interest. If other segment fields are
  used, you may get more than one row per country.
  
  
  Attributes:
      resource_name:
          The resource name of the geographic view. Geographic view
          resource names have the form:  ``customers/{customer_id}/geogr
          aphicViews/{country_criterion_id}~{location_type}``
      location_type:
          Type of the geo targeting of the campaign.
      country_criterion_id:
          Criterion Id for the country.
  """,
  # @@protoc_insertion_point(class_scope:google.ads.googleads.v2.resources.GeographicView)
  ))
_sym_db.RegisterMessage(GeographicView)


DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: google/ads/googleads_v1/proto/errors/multiplier_error.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='google/ads/googleads_v1/proto/errors/multiplier_error.proto',
  package='google.ads.googleads.v1.errors',
  syntax='proto3',
  serialized_options=_b('\n\"com.google.ads.googleads.v1.errorsB\024MultiplierErrorProtoP\001ZDgoogle.golang.org/genproto/googleapis/ads/googleads/v1/errors;errors\242\002\003GAA\252\002\036Google.Ads.GoogleAds.V1.Errors\312\002\036Google\\Ads\\GoogleAds\\V1\\Errors\352\002\"Google::Ads::GoogleAds::V1::Errors'),
  serialized_pb=_b('\n;google/ads/googleads_v1/proto/errors/multiplier_error.proto\x12\x1egoogle.ads.googleads.v1.errors\x1a\x1cgoogle/api/annotations.proto\"\xcf\x04\n\x13MultiplierErrorEnum\"\xb7\x04\n\x0fMultiplierError\x12\x0f\n\x0bUNSPECIFIED\x10\x00\x12\x0b\n\x07UNKNOWN\x10\x01\x12\x17\n\x13MULTIPLIER_TOO_HIGH\x10\x02\x12\x16\n\x12MULTIPLIER_TOO_LOW\x10\x03\x12\x1e\n\x1aTOO_MANY_FRACTIONAL_DIGITS\x10\x04\x12/\n+MULTIPLIER_NOT_ALLOWED_FOR_BIDDING_STRATEGY\x10\x05\x12\x33\n/MULTIPLIER_NOT_ALLOWED_WHEN_BASE_BID_IS_MISSING\x10\x06\x12\x1b\n\x17NO_MULTIPLIER_SPECIFIED\x10\x07\x12\x30\n,MULTIPLIER_CAUSES_BID_TO_EXCEED_DAILY_BUDGET\x10\x08\x12\x32\n.MULTIPLIER_CAUSES_BID_TO_EXCEED_MONTHLY_BUDGET\x10\t\x12\x31\n-MULTIPLIER_CAUSES_BID_TO_EXCEED_CUSTOM_BUDGET\x10\n\x12\x33\n/MULTIPLIER_CAUSES_BID_TO_EXCEED_MAX_ALLOWED_BID\x10\x0b\x12\x31\n-BID_LESS_THAN_MIN_ALLOWED_BID_WITH_MULTIPLIER\x10\x0c\x12\x31\n-MULTIPLIER_AND_BIDDING_STRATEGY_TYPE_MISMATCH\x10\rB\xef\x01\n\"com.google.ads.googleads.v1.errorsB\x14MultiplierErrorProtoP\x01ZDgoogle.golang.org/genproto/googleapis/ads/googleads/v1/errors;errors\xa2\x02\x03GAA\xaa\x02\x1eGoogle.Ads.GoogleAds.V1.Errors\xca\x02\x1eGoogle\\Ads\\GoogleAds\\V1\\Errors\xea\x02\"Google::Ads::GoogleAds::V1::Errorsb\x06proto3')
  ,
  dependencies=[google_dot_api_dot_annotations__pb2.DESCRIPTOR,])



_MULTIPLIERERRORENUM_MULTIPLIERERROR = _descriptor.EnumDescriptor(
  name='MultiplierError',
  full_name='google.ads.googleads.v1.errors.MultiplierErrorEnum.MultiplierError',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='UNSPECIFIED', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='UNKNOWN', index=1, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='MULTIPLIER_TOO_HIGH', index=2, number=2,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='MULTIPLIER_TOO_LOW', index=3, number=3,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='TOO_MANY_FRACTIONAL_DIGITS', index=4, number=4,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='MULTIPLIER_NOT_ALLOWED_FOR_BIDDING_STRATEGY', index=5, number=5,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='MULTIPLIER_NOT_ALLOWED_WHEN_BASE_BID_IS_MISSING', index=6, number=6,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='NO_MULTIPLIER_SPECIFIED', index=7, number=7,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='MULTIPLIER_CAUSES_BID_TO_EXCEED_DAILY_BUDGET', index=8, number=8,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='MULTIPLIER_CAUSES_BID_TO_EXCEED_MONTHLY_BUDGET', index=9, number=9,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='MULTIPLIER_CAUSES_BID_TO_EXCEED_CUSTOM_BUDGET', index=10, number=10,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='MULTIPLIER_CAUSES_BID_TO_EXCEED_MAX_ALLOWED_BID', index=11, number=11,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='BID_LESS_THAN_MIN_ALLOWED_BID_WITH_MULTIPLIER', index=12, number=12,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='MULTIPLIER_AND_BIDDING_STRATEGY_TYPE_MISMATCH', index=13, number=13,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=150,
  serialized_end=717,
)
_sym_db.RegisterEnumDescriptor(_MULTIPLIERERRORENUM_MULTIPLIERERROR)


_MULTIPLIERERRORENUM = _descriptor.Descriptor(
  name='MultiplierErrorEnum',
  full_name='google.ads.googleads.v1.errors.MultiplierErrorEnum',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _MULTIPLIERERRORENUM_MULTIPLIERERROR,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=126,
  serialized_end=717,
)

_MULTIPLIERERRORENUM_MULTIPLIERERROR.containing_type = _MULTIPLIERERRORENUM
DESCRIPTOR.message_types_by_name['MultiplierErrorEnum'] = _MULTIPLIERERRORENUM
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

MultiplierErrorEnum = _reflection.GeneratedProtocolMessageType('MultiplierErrorEnum', (_message.Message,), dict(
  DESCRIPTOR = _MULTIPLIERERRORENUM,
  __module__ = 'google.ads.googleads_v1.proto.errors.multiplier_error_pb2'
  ,
  __doc__ = """Container for enum describing possible multiplier errors.
  """,
  # @@protoc_insertion_point(class_scope:google.ads.googleads.v1.errors.MultiplierErrorEnum)
  ))
_sym_db.RegisterMessage(MultiplierErrorEnum)


DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: google/ads/googleads_v1/proto/resources/customer_manager_link.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.ads.google_ads.v1.proto.enums import manager_link_status_pb2 as google_dot_ads_dot_googleads__v1_dot_proto_dot_enums_dot_manager__link__status__pb2
from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2
from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='google/ads/googleads_v1/proto/resources/customer_manager_link.proto',
  package='google.ads.googleads.v1.resources',
  syntax='proto3',
  serialized_options=_b('\n%com.google.ads.googleads.v1.resourcesB\030CustomerManagerLinkProtoP\001ZJgoogle.golang.org/genproto/googleapis/ads/googleads/v1/resources;resources\242\002\003GAA\252\002!Google.Ads.GoogleAds.V1.Resources\312\002!Google\\Ads\\GoogleAds\\V1\\Resources\352\002%Google::Ads::GoogleAds::V1::Resources'),
  serialized_pb=_b('\nCgoogle/ads/googleads_v1/proto/resources/customer_manager_link.proto\x12!google.ads.googleads.v1.resources\x1a=google/ads/googleads_v1/proto/enums/manager_link_status.proto\x1a\x1egoogle/protobuf/wrappers.proto\x1a\x1cgoogle/api/annotations.proto\"\xf2\x01\n\x13\x43ustomerManagerLink\x12\x15\n\rresource_name\x18\x01 \x01(\t\x12\x36\n\x10manager_customer\x18\x03 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12\x34\n\x0fmanager_link_id\x18\x04 \x01(\x0b\x32\x1b.google.protobuf.Int64Value\x12V\n\x06status\x18\x05 \x01(\x0e\x32\x46.google.ads.googleads.v1.enums.ManagerLinkStatusEnum.ManagerLinkStatusB\x85\x02\n%com.google.ads.googleads.v1.resourcesB\x18\x43ustomerManagerLinkProtoP\x01ZJgoogle.golang.org/genproto/googleapis/ads/googleads/v1/resources;resources\xa2\x02\x03GAA\xaa\x02!Google.Ads.GoogleAds.V1.Resources\xca\x02!Google\\Ads\\GoogleAds\\V1\\Resources\xea\x02%Google::Ads::GoogleAds::V1::Resourcesb\x06proto3')
  ,
  dependencies=[google_dot_ads_dot_googleads__v1_dot_proto_dot_enums_dot_manager__link__status__pb2.DESCRIPTOR,google_dot_protobuf_dot_wrappers__pb2.DESCRIPTOR,google_dot_api_dot_annotations__pb2.DESCRIPTOR,])




_CUSTOMERMANAGERLINK = _descriptor.Descriptor(
  name='CustomerManagerLink',
  full_name='google.ads.googleads.v1.resources.CustomerManagerLink',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='resource_name', full_name='google.ads.googleads.v1.resources.CustomerManagerLink.resource_name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='manager_customer', full_name='google.ads.googleads.v1.resources.CustomerManagerLink.manager_customer', index=1,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='manager_link_id', full_name='google.ads.googleads.v1.resources.CustomerManagerLink.manager_link_id', index=2,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='status', full_name='google.ads.googleads.v1.resources.CustomerManagerLink.status', index=3,
      number=5, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=232,
  serialized_end=474,
)

_CUSTOMERMANAGERLINK.fields_by_name['manager_customer'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
_CUSTOMERMANAGERLINK.fields_by_name['manager_link_id'].message_type = google_dot_protobuf_dot_wrappers__pb2._INT64VALUE
_CUSTOMERMANAGERLINK.fields_by_name['status'].enum_type = google_dot_ads_dot_googleads__v1_dot_proto_dot_enums_dot_manager__link__status__pb2._MANAGERLINKSTATUSENUM_MANAGERLINKSTATUS
DESCRIPTOR.message_types_by_name['CustomerManagerLink'] = _CUSTOMERMANAGERLINK
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

CustomerManagerLink = _reflection.GeneratedProtocolMessageType('CustomerManagerLink', (_message.Message,), dict(
  DESCRIPTOR = _CUSTOMERMANAGERLINK,
  __module__ = 'google.ads.googleads_v1.proto.resources.customer_manager_link_pb2'
  ,
  __doc__ = """Represents customer-manager link relationship.
  
  
  Attributes:
      resource_name:
          Name of the resource. CustomerManagerLink resource names have
          the form:  ``customers/{customer_id}/customerManagerLinks/{man
          ager_customer_id}~{manager_link_id}``
      manager_customer:
          The manager customer linked to the customer.
      manager_link_id:
          ID of the customer-manager link. This field is read only.
      status:
          Status of the link between the customer and the manager.
  """,
  # @@protoc_insertion_point(class_scope:google.ads.googleads.v1.resources.CustomerManagerLink)
  ))
_sym_db.RegisterMessage(CustomerManagerLink)


DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: google/ads/googleads_v2/proto/errors/campaign_draft_error.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='google/ads/googleads_v2/proto/errors/campaign_draft_error.proto',
  package='google.ads.googleads.v2.errors',
  syntax='proto3',
  serialized_options=_b('\n\"com.google.ads.googleads.v2.errorsB\027CampaignDraftErrorProtoP\001ZDgoogle.golang.org/genproto/googleapis/ads/googleads/v2/errors;errors\242\002\003GAA\252\002\036Google.Ads.GoogleAds.V2.Errors\312\002\036Google\\Ads\\GoogleAds\\V2\\Errors\352\002\"Google::Ads::GoogleAds::V2::Errors'),
  serialized_pb=_b('\n?google/ads/googleads_v2/proto/errors/campaign_draft_error.proto\x12\x1egoogle.ads.googleads.v2.errors\x1a\x1cgoogle/api/annotations.proto\"\xc8\x03\n\x16\x43\x61mpaignDraftErrorEnum\"\xad\x03\n\x12\x43\x61mpaignDraftError\x12\x0f\n\x0bUNSPECIFIED\x10\x00\x12\x0b\n\x07UNKNOWN\x10\x01\x12\x18\n\x14\x44UPLICATE_DRAFT_NAME\x10\x02\x12*\n&INVALID_STATUS_TRANSITION_FROM_REMOVED\x10\x03\x12+\n\'INVALID_STATUS_TRANSITION_FROM_PROMOTED\x10\x04\x12\x31\n-INVALID_STATUS_TRANSITION_FROM_PROMOTE_FAILED\x10\x05\x12 \n\x1c\x43USTOMER_CANNOT_CREATE_DRAFT\x10\x06\x12 \n\x1c\x43\x41MPAIGN_CANNOT_CREATE_DRAFT\x10\x07\x12\x18\n\x14INVALID_DRAFT_CHANGE\x10\x08\x12\x1d\n\x19INVALID_STATUS_TRANSITION\x10\t\x12-\n)MAX_NUMBER_OF_DRAFTS_PER_CAMPAIGN_REACHED\x10\n\x12\'\n#LIST_ERRORS_FOR_PROMOTED_DRAFT_ONLY\x10\x0b\x42\xf2\x01\n\"com.google.ads.googleads.v2.errorsB\x17\x43\x61mpaignDraftErrorProtoP\x01ZDgoogle.golang.org/genproto/googleapis/ads/googleads/v2/errors;errors\xa2\x02\x03GAA\xaa\x02\x1eGoogle.Ads.GoogleAds.V2.Errors\xca\x02\x1eGoogle\\Ads\\GoogleAds\\V2\\Errors\xea\x02\"Google::Ads::GoogleAds::V2::Errorsb\x06proto3')
  ,
  dependencies=[google_dot_api_dot_annotations__pb2.DESCRIPTOR,])



_CAMPAIGNDRAFTERRORENUM_CAMPAIGNDRAFTERROR = _descriptor.EnumDescriptor(
  name='CampaignDraftError',
  full_name='google.ads.googleads.v2.errors.CampaignDraftErrorEnum.CampaignDraftError',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='UNSPECIFIED', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='UNKNOWN', index=1, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='DUPLICATE_DRAFT_NAME', index=2, number=2,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='INVALID_STATUS_TRANSITION_FROM_REMOVED', index=3, number=3,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='INVALID_STATUS_TRANSITION_FROM_PROMOTED', index=4, number=4,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='INVALID_STATUS_TRANSITION_FROM_PROMOTE_FAILED', index=5, number=5,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='CUSTOMER_CANNOT_CREATE_DRAFT', index=6, number=6,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='CAMPAIGN_CANNOT_CREATE_DRAFT', index=7, number=7,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='INVALID_DRAFT_CHANGE', index=8, number=8,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='INVALID_STATUS_TRANSITION', index=9, number=9,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='MAX_NUMBER_OF_DRAFTS_PER_CAMPAIGN_REACHED', index=10, number=10,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='LIST_ERRORS_FOR_PROMOTED_DRAFT_ONLY', index=11, number=11,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=157,
  serialized_end=586,
)
_sym_db.RegisterEnumDescriptor(_CAMPAIGNDRAFTERRORENUM_CAMPAIGNDRAFTERROR)


_CAMPAIGNDRAFTERRORENUM = _descriptor.Descriptor(
  name='CampaignDraftErrorEnum',
  full_name='google.ads.googleads.v2.errors.CampaignDraftErrorEnum',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _CAMPAIGNDRAFTERRORENUM_CAMPAIGNDRAFTERROR,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=130,
  serialized_end=586,
)

_CAMPAIGNDRAFTERRORENUM_CAMPAIGNDRAFTERROR.containing_type = _CAMPAIGNDRAFTERRORENUM
DESCRIPTOR.message_types_by_name['CampaignDraftErrorEnum'] = _CAMPAIGNDRAFTERRORENUM
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

CampaignDraftErrorEnum = _reflection.GeneratedProtocolMessageType('CampaignDraftErrorEnum', (_message.Message,), dict(
  DESCRIPTOR = _CAMPAIGNDRAFTERRORENUM,
  __module__ = 'google.ads.googleads_v2.proto.errors.campaign_draft_error_pb2'
  ,
  __doc__ = """Container for enum describing possible campaign draft errors.
  """,
  # @@protoc_insertion_point(class_scope:google.ads.googleads.v2.errors.CampaignDraftErrorEnum)
  ))
_sym_db.RegisterMessage(CampaignDraftErrorEnum)


DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)



# Copyright 2018 Google LLC
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     https://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
"""A setup module for the Google Ads API client library."""

from setuptools import setup, find_packages
import io

install_requires = [
    'google-auth-oauthlib >= 0.3.0, < 1.0.0',
    'google-api-core >= 1.14.0, < 2.0.0',
    'googleapis-common-protos >= 1.5.8, < 2.0.0',
    'grpcio >= 1.25.0, < 2.0.0',
    'PyYAML >= 5.1, < 6.0',
]

tests_require = [
    'mock >= 3.0.0, < 4.0.0',
    'pyfakefs >= 3.5, < 3.6',
]

with io.open('README.rst', 'r', encoding='utf-8') as readme_file:
    long_description = readme_file.read()

setup(
    name='google-ads',
    version='4.1.1',
    author='Google LLC',
    author_email='googleapis-packages@google.com',
    classifiers=[
        'Intended Audience :: Developers',
        'Development Status :: 3 - Alpha',
        'Intended Audience :: Developers',
        'License :: OSI Approved :: Apache Software License',
        'Programming Language :: Python',
        'Programming Language :: Python :: 3',
        'Programming Language :: Python :: 3.7',
    ],
    description='Client library for the Google Ads API',
    include_package_data=True,
    python_requires='>=3.7',
    long_description=long_description,
    install_requires=install_requires,
    tests_require=tests_require,
    test_suite='tests',
    license='Apache 2.0',
    packages=find_packages(exclude=['examples', 'examples.*', 'tests', 'tests.*']),
    namespace_packages=['google', 'google.ads'],
    url='https://github.com/googleads/google-ads-python',
    zip_safe=False,
)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: google/ads/googleads_v2/proto/services/merchant_center_link_service.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.ads.google_ads.v2.proto.resources import merchant_center_link_pb2 as google_dot_ads_dot_googleads__v2_dot_proto_dot_resources_dot_merchant__center__link__pb2
from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from google.protobuf import field_mask_pb2 as google_dot_protobuf_dot_field__mask__pb2
from google.api import client_pb2 as google_dot_api_dot_client__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='google/ads/googleads_v2/proto/services/merchant_center_link_service.proto',
  package='google.ads.googleads.v2.services',
  syntax='proto3',
  serialized_options=_b('\n$com.google.ads.googleads.v2.servicesB\036MerchantCenterLinkServiceProtoP\001ZHgoogle.golang.org/genproto/googleapis/ads/googleads/v2/services;services\242\002\003GAA\252\002 Google.Ads.GoogleAds.V2.Services\312\002 Google\\Ads\\GoogleAds\\V2\\Services\352\002$Google::Ads::GoogleAds::V2::Services'),
  serialized_pb=_b('\nIgoogle/ads/googleads_v2/proto/services/merchant_center_link_service.proto\x12 google.ads.googleads.v2.services\x1a\x42google/ads/googleads_v2/proto/resources/merchant_center_link.proto\x1a\x1cgoogle/api/annotations.proto\x1a google/protobuf/field_mask.proto\x1a\x17google/api/client.proto\"5\n\x1eListMerchantCenterLinksRequest\x12\x13\n\x0b\x63ustomer_id\x18\x01 \x01(\t\"w\n\x1fListMerchantCenterLinksResponse\x12T\n\x15merchant_center_links\x18\x01 \x03(\x0b\x32\x35.google.ads.googleads.v2.resources.MerchantCenterLink\"5\n\x1cGetMerchantCenterLinkRequest\x12\x15\n\rresource_name\x18\x01 \x01(\t\"\x88\x01\n\x1fMutateMerchantCenterLinkRequest\x12\x13\n\x0b\x63ustomer_id\x18\x01 \x01(\t\x12P\n\toperation\x18\x02 \x01(\x0b\x32=.google.ads.googleads.v2.services.MerchantCenterLinkOperation\"\xb6\x01\n\x1bMerchantCenterLinkOperation\x12/\n\x0bupdate_mask\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.FieldMask\x12G\n\x06update\x18\x01 \x01(\x0b\x32\x35.google.ads.googleads.v2.resources.MerchantCenterLinkH\x00\x12\x10\n\x06remove\x18\x02 \x01(\tH\x00\x42\x0b\n\toperation\"t\n MutateMerchantCenterLinkResponse\x12P\n\x06result\x18\x02 \x01(\x0b\x32@.google.ads.googleads.v2.services.MutateMerchantCenterLinkResult\"7\n\x1eMutateMerchantCenterLinkResult\x12\x15\n\rresource_name\x18\x01 \x01(\t2\xcd\x05\n\x19MerchantCenterLinkService\x12\xd9\x01\n\x17ListMerchantCenterLinks\x12@.google.ads.googleads.v2.services.ListMerchantCenterLinksRequest\x1a\x41.google.ads.googleads.v2.services.ListMerchantCenterLinksResponse\"9\x82\xd3\xe4\x93\x02\x33\x12\x31/v2/customers/{customer_id=*}/merchantCenterLinks\x12\xcd\x01\n\x15GetMerchantCenterLink\x12>.google.ads.googleads.v2.services.GetMerchantCenterLinkRequest\x1a\x35.google.ads.googleads.v2.resources.MerchantCenterLink\"=\x82\xd3\xe4\x93\x02\x37\x12\x35/v2/{resource_name=customers/*/merchantCenterLinks/*}\x12\xe6\x01\n\x18MutateMerchantCenterLink\x12\x41.google.ads.googleads.v2.services.MutateMerchantCenterLinkRequest\x1a\x42.google.ads.googleads.v2.services.MutateMerchantCenterLinkResponse\"C\x82\xd3\xe4\x93\x02=\"8/v2/customers/{customer_id=*}/merchantCenterLinks:mutate:\x01*\x1a\x1b\xca\x41\x18googleads.googleapis.comB\x85\x02\n$com.google.ads.googleads.v2.servicesB\x1eMerchantCenterLinkServiceProtoP\x01ZHgoogle.golang.org/genproto/googleapis/ads/googleads/v2/services;services\xa2\x02\x03GAA\xaa\x02 Google.Ads.GoogleAds.V2.Services\xca\x02 Google\\Ads\\GoogleAds\\V2\\Services\xea\x02$Google::Ads::GoogleAds::V2::Servicesb\x06proto3')
  ,
  dependencies=[google_dot_ads_dot_googleads__v2_dot_proto_dot_resources_dot_merchant__center__link__pb2.DESCRIPTOR,google_dot_api_dot_annotations__pb2.DESCRIPTOR,google_dot_protobuf_dot_field__mask__pb2.DESCRIPTOR,google_dot_api_dot_client__pb2.DESCRIPTOR,])




_LISTMERCHANTCENTERLINKSREQUEST = _descriptor.Descriptor(
  name='ListMerchantCenterLinksRequest',
  full_name='google.ads.googleads.v2.services.ListMerchantCenterLinksRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='customer_id', full_name='google.ads.googleads.v2.services.ListMerchantCenterLinksRequest.customer_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=268,
  serialized_end=321,
)


_LISTMERCHANTCENTERLINKSRESPONSE = _descriptor.Descriptor(
  name='ListMerchantCenterLinksResponse',
  full_name='google.ads.googleads.v2.services.ListMerchantCenterLinksResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='merchant_center_links', full_name='google.ads.googleads.v2.services.ListMerchantCenterLinksResponse.merchant_center_links', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=323,
  serialized_end=442,
)


_GETMERCHANTCENTERLINKREQUEST = _descriptor.Descriptor(
  name='GetMerchantCenterLinkRequest',
  full_name='google.ads.googleads.v2.services.GetMerchantCenterLinkRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='resource_name', full_name='google.ads.googleads.v2.services.GetMerchantCenterLinkRequest.resource_name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=444,
  serialized_end=497,
)


_MUTATEMERCHANTCENTERLINKREQUEST = _descriptor.Descriptor(
  name='MutateMerchantCenterLinkRequest',
  full_name='google.ads.googleads.v2.services.MutateMerchantCenterLinkRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='customer_id', full_name='google.ads.googleads.v2.services.MutateMerchantCenterLinkRequest.customer_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='operation', full_name='google.ads.googleads.v2.services.MutateMerchantCenterLinkRequest.operation', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=500,
  serialized_end=636,
)


_MERCHANTCENTERLINKOPERATION = _descriptor.Descriptor(
  name='MerchantCenterLinkOperation',
  full_name='google.ads.googleads.v2.services.MerchantCenterLinkOperation',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='update_mask', full_name='google.ads.googleads.v2.services.MerchantCenterLinkOperation.update_mask', index=0,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='update', full_name='google.ads.googleads.v2.services.MerchantCenterLinkOperation.update', index=1,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='remove', full_name='google.ads.googleads.v2.services.MerchantCenterLinkOperation.remove', index=2,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='operation', full_name='google.ads.googleads.v2.services.MerchantCenterLinkOperation.operation',
      index=0, containing_type=None, fields=[]),
  ],
  serialized_start=639,
  serialized_end=821,
)


_MUTATEMERCHANTCENTERLINKRESPONSE = _descriptor.Descriptor(
  name='MutateMerchantCenterLinkResponse',
  full_name='google.ads.googleads.v2.services.MutateMerchantCenterLinkResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='result', full_name='google.ads.googleads.v2.services.MutateMerchantCenterLinkResponse.result', index=0,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=823,
  serialized_end=939,
)


_MUTATEMERCHANTCENTERLINKRESULT = _descriptor.Descriptor(
  name='MutateMerchantCenterLinkResult',
  full_name='google.ads.googleads.v2.services.MutateMerchantCenterLinkResult',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='resource_name', full_name='google.ads.googleads.v2.services.MutateMerchantCenterLinkResult.resource_name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=941,
  serialized_end=996,
)

_LISTMERCHANTCENTERLINKSRESPONSE.fields_by_name['merchant_center_links'].message_type = google_dot_ads_dot_googleads__v2_dot_proto_dot_resources_dot_merchant__center__link__pb2._MERCHANTCENTERLINK
_MUTATEMERCHANTCENTERLINKREQUEST.fields_by_name['operation'].message_type = _MERCHANTCENTERLINKOPERATION
_MERCHANTCENTERLINKOPERATION.fields_by_name['update_mask'].message_type = google_dot_protobuf_dot_field__mask__pb2._FIELDMASK
_MERCHANTCENTERLINKOPERATION.fields_by_name['update'].message_type = google_dot_ads_dot_googleads__v2_dot_proto_dot_resources_dot_merchant__center__link__pb2._MERCHANTCENTERLINK
_MERCHANTCENTERLINKOPERATION.oneofs_by_name['operation'].fields.append(
  _MERCHANTCENTERLINKOPERATION.fields_by_name['update'])
_MERCHANTCENTERLINKOPERATION.fields_by_name['update'].containing_oneof = _MERCHANTCENTERLINKOPERATION.oneofs_by_name['operation']
_MERCHANTCENTERLINKOPERATION.oneofs_by_name['operation'].fields.append(
  _MERCHANTCENTERLINKOPERATION.fields_by_name['remove'])
_MERCHANTCENTERLINKOPERATION.fields_by_name['remove'].containing_oneof = _MERCHANTCENTERLINKOPERATION.oneofs_by_name['operation']
_MUTATEMERCHANTCENTERLINKRESPONSE.fields_by_name['result'].message_type = _MUTATEMERCHANTCENTERLINKRESULT
DESCRIPTOR.message_types_by_name['ListMerchantCenterLinksRequest'] = _LISTMERCHANTCENTERLINKSREQUEST
DESCRIPTOR.message_types_by_name['ListMerchantCenterLinksResponse'] = _LISTMERCHANTCENTERLINKSRESPONSE
DESCRIPTOR.message_types_by_name['GetMerchantCenterLinkRequest'] = _GETMERCHANTCENTERLINKREQUEST
DESCRIPTOR.message_types_by_name['MutateMerchantCenterLinkRequest'] = _MUTATEMERCHANTCENTERLINKREQUEST
DESCRIPTOR.message_types_by_name['MerchantCenterLinkOperation'] = _MERCHANTCENTERLINKOPERATION
DESCRIPTOR.message_types_by_name['MutateMerchantCenterLinkResponse'] = _MUTATEMERCHANTCENTERLINKRESPONSE
DESCRIPTOR.message_types_by_name['MutateMerchantCenterLinkResult'] = _MUTATEMERCHANTCENTERLINKRESULT
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

ListMerchantCenterLinksRequest = _reflection.GeneratedProtocolMessageType('ListMerchantCenterLinksRequest', (_message.Message,), dict(
  DESCRIPTOR = _LISTMERCHANTCENTERLINKSREQUEST,
  __module__ = 'google.ads.googleads_v2.proto.services.merchant_center_link_service_pb2'
  ,
  __doc__ = """Request message for
  [MerchantCenterLinkService.ListMerchantCenterLinks][google.ads.googleads.v2.services.MerchantCenterLinkService.ListMerchantCenterLinks].
  
  
  Attributes:
      customer_id:
          The ID of the customer onto which to apply the Merchant Center
          link list operation.
  """,
  # @@protoc_insertion_point(class_scope:google.ads.googleads.v2.services.ListMerchantCenterLinksRequest)
  ))
_sym_db.RegisterMessage(ListMerchantCenterLinksRequest)

ListMerchantCenterLinksResponse = _reflection.GeneratedProtocolMessageType('ListMerchantCenterLinksResponse', (_message.Message,), dict(
  DESCRIPTOR = _LISTMERCHANTCENTERLINKSRESPONSE,
  __module__ = 'google.ads.googleads_v2.proto.services.merchant_center_link_service_pb2'
  ,
  __doc__ = """Response message for
  [MerchantCenterLinkService.ListMerchantCenterLinks][google.ads.googleads.v2.services.MerchantCenterLinkService.ListMerchantCenterLinks].
  
  
  Attributes:
      merchant_center_links:
          Merchant Center links available for the requested customer
  """,
  # @@protoc_insertion_point(class_scope:google.ads.googleads.v2.services.ListMerchantCenterLinksResponse)
  ))
_sym_db.RegisterMessage(ListMerchantCenterLinksResponse)

GetMerchantCenterLinkRequest = _reflection.GeneratedProtocolMessageType('GetMerchantCenterLinkRequest', (_message.Message,), dict(
  DESCRIPTOR = _GETMERCHANTCENTERLINKREQUEST,
  __module__ = 'google.ads.googleads_v2.proto.services.merchant_center_link_service_pb2'
  ,
  __doc__ = """Request message for
  [MerchantCenterLinkService.GetMerchantCenterLink][google.ads.googleads.v2.services.MerchantCenterLinkService.GetMerchantCenterLink].
  
  
  Attributes:
      resource_name:
          Resource name of the Merchant Center link.
  """,
  # @@protoc_insertion_point(class_scope:google.ads.googleads.v2.services.GetMerchantCenterLinkRequest)
  ))
_sym_db.RegisterMessage(GetMerchantCenterLinkRequest)

MutateMerchantCenterLinkRequest = _reflection.GeneratedProtocolMessageType('MutateMerchantCenterLinkRequest', (_message.Message,), dict(
  DESCRIPTOR = _MUTATEMERCHANTCENTERLINKREQUEST,
  __module__ = 'google.ads.googleads_v2.proto.services.merchant_center_link_service_pb2'
  ,
  __doc__ = """Request message for
  [MerchantCenterLinkService.MutateMerchantCenterLink][google.ads.googleads.v2.services.MerchantCenterLinkService.MutateMerchantCenterLink].
  
  
  Attributes:
      customer_id:
          The ID of the customer being modified.
      operation:
          The operation to perform on the link
  """,
  # @@protoc_insertion_point(class_scope:google.ads.googleads.v2.services.MutateMerchantCenterLinkRequest)
  ))
_sym_db.RegisterMessage(MutateMerchantCenterLinkRequest)

MerchantCenterLinkOperation = _reflection.GeneratedProtocolMessageType('MerchantCenterLinkOperation', (_message.Message,), dict(
  DESCRIPTOR = _MERCHANTCENTERLINKOPERATION,
  __module__ = 'google.ads.googleads_v2.proto.services.merchant_center_link_service_pb2'
  ,
  __doc__ = """A single update on a Merchant Center link.
  
  
  Attributes:
      update_mask:
          FieldMask that determines which resource fields are modified
          in an update.
      operation:
          The operation to perform
      update:
          Update operation: The merchant center link is expected to have
          a valid resource name.
      remove:
          Remove operation: A resource name for the removed merchant
          center link is expected, in this format:  ``customers/{custome
          r_id}/merchantCenterLinks/{merchant_center_id}``
  """,
  # @@protoc_insertion_point(class_scope:google.ads.googleads.v2.services.MerchantCenterLinkOperation)
  ))
_sym_db.RegisterMessage(MerchantCenterLinkOperation)

MutateMerchantCenterLinkResponse = _reflection.GeneratedProtocolMessageType('MutateMerchantCenterLinkResponse', (_message.Message,), dict(
  DESCRIPTOR = _MUTATEMERCHANTCENTERLINKRESPONSE,
  __module__ = 'google.ads.googleads_v2.proto.services.merchant_center_link_service_pb2'
  ,
  __doc__ = """Response message for Merchant Center link mutate.
  
  
  Attributes:
      result:
          Result for the mutate.
  """,
  # @@protoc_insertion_point(class_scope:google.ads.googleads.v2.services.MutateMerchantCenterLinkResponse)
  ))
_sym_db.RegisterMessage(MutateMerchantCenterLinkResponse)

MutateMerchantCenterLinkResult = _reflection.GeneratedProtocolMessageType('MutateMerchantCenterLinkResult', (_message.Message,), dict(
  DESCRIPTOR = _MUTATEMERCHANTCENTERLINKRESULT,
  __module__ = 'google.ads.googleads_v2.proto.services.merchant_center_link_service_pb2'
  ,
  __doc__ = """The result for the Merchant Center link mutate.
  
  
  Attributes:
      resource_name:
          Returned for successful operations.
  """,
  # @@protoc_insertion_point(class_scope:google.ads.googleads.v2.services.MutateMerchantCenterLinkResult)
  ))
_sym_db.RegisterMessage(MutateMerchantCenterLinkResult)


DESCRIPTOR._options = None

_MERCHANTCENTERLINKSERVICE = _descriptor.ServiceDescriptor(
  name='MerchantCenterLinkService',
  full_name='google.ads.googleads.v2.services.MerchantCenterLinkService',
  file=DESCRIPTOR,
  index=0,
  serialized_options=_b('\312A\030googleads.googleapis.com'),
  serialized_start=999,
  serialized_end=1716,
  methods=[
  _descriptor.MethodDescriptor(
    name='ListMerchantCenterLinks',
    full_name='google.ads.googleads.v2.services.MerchantCenterLinkService.ListMerchantCenterLinks',
    index=0,
    containing_service=None,
    input_type=_LISTMERCHANTCENTERLINKSREQUEST,
    output_type=_LISTMERCHANTCENTERLINKSRESPONSE,
    serialized_options=_b('\202\323\344\223\0023\0221/v2/customers/{customer_id=*}/merchantCenterLinks'),
  ),
  _descriptor.MethodDescriptor(
    name='GetMerchantCenterLink',
    full_name='google.ads.googleads.v2.services.MerchantCenterLinkService.GetMerchantCenterLink',
    index=1,
    containing_service=None,
    input_type=_GETMERCHANTCENTERLINKREQUEST,
    output_type=google_dot_ads_dot_googleads__v2_dot_proto_dot_resources_dot_merchant__center__link__pb2._MERCHANTCENTERLINK,
    serialized_options=_b('\202\323\344\223\0027\0225/v2/{resource_name=customers/*/merchantCenterLinks/*}'),
  ),
  _descriptor.MethodDescriptor(
    name='MutateMerchantCenterLink',
    full_name='google.ads.googleads.v2.services.MerchantCenterLinkService.MutateMerchantCenterLink',
    index=2,
    containing_service=None,
    input_type=_MUTATEMERCHANTCENTERLINKREQUEST,
    output_type=_MUTATEMERCHANTCENTERLINKRESPONSE,
    serialized_options=_b('\202\323\344\223\002=\"8/v2/customers/{customer_id=*}/merchantCenterLinks:mutate:\001*'),
  ),
])
_sym_db.RegisterServiceDescriptor(_MERCHANTCENTERLINKSERVICE)

DESCRIPTOR.services_by_name['MerchantCenterLinkService'] = _MERCHANTCENTERLINKSERVICE

# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: google/ads/googleads_v1/proto/services/google_ads_field_service.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.ads.google_ads.v1.proto.resources import google_ads_field_pb2 as google_dot_ads_dot_googleads__v1_dot_proto_dot_resources_dot_google__ads__field__pb2
from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='google/ads/googleads_v1/proto/services/google_ads_field_service.proto',
  package='google.ads.googleads.v1.services',
  syntax='proto3',
  serialized_options=_b('\n$com.google.ads.googleads.v1.servicesB\032GoogleAdsFieldServiceProtoP\001ZHgoogle.golang.org/genproto/googleapis/ads/googleads/v1/services;services\242\002\003GAA\252\002 Google.Ads.GoogleAds.V1.Services\312\002 Google\\Ads\\GoogleAds\\V1\\Services\352\002$Google::Ads::GoogleAds::V1::Services'),
  serialized_pb=_b('\nEgoogle/ads/googleads_v1/proto/services/google_ads_field_service.proto\x12 google.ads.googleads.v1.services\x1a>google/ads/googleads_v1/proto/resources/google_ads_field.proto\x1a\x1cgoogle/api/annotations.proto\"1\n\x18GetGoogleAdsFieldRequest\x12\x15\n\rresource_name\x18\x01 \x01(\t\"T\n\x1cSearchGoogleAdsFieldsRequest\x12\r\n\x05query\x18\x01 \x01(\t\x12\x12\n\npage_token\x18\x02 \x01(\t\x12\x11\n\tpage_size\x18\x03 \x01(\x05\"\x99\x01\n\x1dSearchGoogleAdsFieldsResponse\x12\x42\n\x07results\x18\x01 \x03(\x0b\x32\x31.google.ads.googleads.v1.resources.GoogleAdsField\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\x12\x1b\n\x13total_results_count\x18\x03 \x01(\x03\x32\x8d\x03\n\x15GoogleAdsFieldService\x12\xb1\x01\n\x11GetGoogleAdsField\x12:.google.ads.googleads.v1.services.GetGoogleAdsFieldRequest\x1a\x31.google.ads.googleads.v1.resources.GoogleAdsField\"-\x82\xd3\xe4\x93\x02\'\x12%/v1/{resource_name=googleAdsFields/*}\x12\xbf\x01\n\x15SearchGoogleAdsFields\x12>.google.ads.googleads.v1.services.SearchGoogleAdsFieldsRequest\x1a?.google.ads.googleads.v1.services.SearchGoogleAdsFieldsResponse\"%\x82\xd3\xe4\x93\x02\x1f\"\x1a/v1/googleAdsFields:search:\x01*B\x81\x02\n$com.google.ads.googleads.v1.servicesB\x1aGoogleAdsFieldServiceProtoP\x01ZHgoogle.golang.org/genproto/googleapis/ads/googleads/v1/services;services\xa2\x02\x03GAA\xaa\x02 Google.Ads.GoogleAds.V1.Services\xca\x02 Google\\Ads\\GoogleAds\\V1\\Services\xea\x02$Google::Ads::GoogleAds::V1::Servicesb\x06proto3')
  ,
  dependencies=[google_dot_ads_dot_googleads__v1_dot_proto_dot_resources_dot_google__ads__field__pb2.DESCRIPTOR,google_dot_api_dot_annotations__pb2.DESCRIPTOR,])




_GETGOOGLEADSFIELDREQUEST = _descriptor.Descriptor(
  name='GetGoogleAdsFieldRequest',
  full_name='google.ads.googleads.v1.services.GetGoogleAdsFieldRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='resource_name', full_name='google.ads.googleads.v1.services.GetGoogleAdsFieldRequest.resource_name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=201,
  serialized_end=250,
)


_SEARCHGOOGLEADSFIELDSREQUEST = _descriptor.Descriptor(
  name='SearchGoogleAdsFieldsRequest',
  full_name='google.ads.googleads.v1.services.SearchGoogleAdsFieldsRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='query', full_name='google.ads.googleads.v1.services.SearchGoogleAdsFieldsRequest.query', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='page_token', full_name='google.ads.googleads.v1.services.SearchGoogleAdsFieldsRequest.page_token', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='page_size', full_name='google.ads.googleads.v1.services.SearchGoogleAdsFieldsRequest.page_size', index=2,
      number=3, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=252,
  serialized_end=336,
)


_SEARCHGOOGLEADSFIELDSRESPONSE = _descriptor.Descriptor(
  name='SearchGoogleAdsFieldsResponse',
  full_name='google.ads.googleads.v1.services.SearchGoogleAdsFieldsResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='results', full_name='google.ads.googleads.v1.services.SearchGoogleAdsFieldsResponse.results', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='next_page_token', full_name='google.ads.googleads.v1.services.SearchGoogleAdsFieldsResponse.next_page_token', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='total_results_count', full_name='google.ads.googleads.v1.services.SearchGoogleAdsFieldsResponse.total_results_count', index=2,
      number=3, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=339,
  serialized_end=492,
)

_SEARCHGOOGLEADSFIELDSRESPONSE.fields_by_name['results'].message_type = google_dot_ads_dot_googleads__v1_dot_proto_dot_resources_dot_google__ads__field__pb2._GOOGLEADSFIELD
DESCRIPTOR.message_types_by_name['GetGoogleAdsFieldRequest'] = _GETGOOGLEADSFIELDREQUEST
DESCRIPTOR.message_types_by_name['SearchGoogleAdsFieldsRequest'] = _SEARCHGOOGLEADSFIELDSREQUEST
DESCRIPTOR.message_types_by_name['SearchGoogleAdsFieldsResponse'] = _SEARCHGOOGLEADSFIELDSRESPONSE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

GetGoogleAdsFieldRequest = _reflection.GeneratedProtocolMessageType('GetGoogleAdsFieldRequest', (_message.Message,), dict(
  DESCRIPTOR = _GETGOOGLEADSFIELDREQUEST,
  __module__ = 'google.ads.googleads_v1.proto.services.google_ads_field_service_pb2'
  ,
  __doc__ = """Request message for
  [GoogleAdsFieldService.GetGoogleAdsField][google.ads.googleads.v1.services.GoogleAdsFieldService.GetGoogleAdsField].
  
  
  Attributes:
      resource_name:
          The resource name of the field to get.
  """,
  # @@protoc_insertion_point(class_scope:google.ads.googleads.v1.services.GetGoogleAdsFieldRequest)
  ))
_sym_db.RegisterMessage(GetGoogleAdsFieldRequest)

SearchGoogleAdsFieldsRequest = _reflection.GeneratedProtocolMessageType('SearchGoogleAdsFieldsRequest', (_message.Message,), dict(
  DESCRIPTOR = _SEARCHGOOGLEADSFIELDSREQUEST,
  __module__ = 'google.ads.googleads_v1.proto.services.google_ads_field_service_pb2'
  ,
  __doc__ = """Request message for
  [GoogleAdsFieldService.SearchGoogleAdsFields][google.ads.googleads.v1.services.GoogleAdsFieldService.SearchGoogleAdsFields].
  
  
  Attributes:
      query:
          The query string.
      page_token:
          Token of the page to retrieve. If not specified, the first
          page of results will be returned. Use the value obtained from
          ``next_page_token`` in the previous response in order to
          request the next page of results.
      page_size:
          Number of elements to retrieve in a single page. When too
          large a page is requested, the server may decide to further
          limit the number of returned resources.
  """,
  # @@protoc_insertion_point(class_scope:google.ads.googleads.v1.services.SearchGoogleAdsFieldsRequest)
  ))
_sym_db.RegisterMessage(SearchGoogleAdsFieldsRequest)

SearchGoogleAdsFieldsResponse = _reflection.GeneratedProtocolMessageType('SearchGoogleAdsFieldsResponse', (_message.Message,), dict(
  DESCRIPTOR = _SEARCHGOOGLEADSFIELDSRESPONSE,
  __module__ = 'google.ads.googleads_v1.proto.services.google_ads_field_service_pb2'
  ,
  __doc__ = """Response message for
  [GoogleAdsFieldService.SearchGoogleAdsFields][google.ads.googleads.v1.services.GoogleAdsFieldService.SearchGoogleAdsFields].
  
  
  Attributes:
      results:
          The list of fields that matched the query.
      next_page_token:
          Pagination token used to retrieve the next page of results.
          Pass the content of this string as the ``page_token``
          attribute of the next request. ``next_page_token`` is not
          returned for the last page.
      total_results_count:
          Total number of results that match the query ignoring the
          LIMIT clause.
  """,
  # @@protoc_insertion_point(class_scope:google.ads.googleads.v1.services.SearchGoogleAdsFieldsResponse)
  ))
_sym_db.RegisterMessage(SearchGoogleAdsFieldsResponse)


DESCRIPTOR._options = None

_GOOGLEADSFIELDSERVICE = _descriptor.ServiceDescriptor(
  name='GoogleAdsFieldService',
  full_name='google.ads.googleads.v1.services.GoogleAdsFieldService',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  serialized_start=495,
  serialized_end=892,
  methods=[
  _descriptor.MethodDescriptor(
    name='GetGoogleAdsField',
    full_name='google.ads.googleads.v1.services.GoogleAdsFieldService.GetGoogleAdsField',
    index=0,
    containing_service=None,
    input_type=_GETGOOGLEADSFIELDREQUEST,
    output_type=google_dot_ads_dot_googleads__v1_dot_proto_dot_resources_dot_google__ads__field__pb2._GOOGLEADSFIELD,
    serialized_options=_b('\202\323\344\223\002\'\022%/v1/{resource_name=googleAdsFields/*}'),
  ),
  _descriptor.MethodDescriptor(
    name='SearchGoogleAdsFields',
    full_name='google.ads.googleads.v1.services.GoogleAdsFieldService.SearchGoogleAdsFields',
    index=1,
    containing_service=None,
    input_type=_SEARCHGOOGLEADSFIELDSREQUEST,
    output_type=_SEARCHGOOGLEADSFIELDSRESPONSE,
    serialized_options=_b('\202\323\344\223\002\037\"\032/v1/googleAdsFields:search:\001*'),
  ),
])
_sym_db.RegisterServiceDescriptor(_GOOGLEADSFIELDSERVICE)

DESCRIPTOR.services_by_name['GoogleAdsFieldService'] = _GOOGLEADSFIELDSERVICE

# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: google/ads/googleads_v2/proto/enums/travel_placeholder_field.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='google/ads/googleads_v2/proto/enums/travel_placeholder_field.proto',
  package='google.ads.googleads.v2.enums',
  syntax='proto3',
  serialized_options=_b('\n!com.google.ads.googleads.v2.enumsB\033TravelPlaceholderFieldProtoP\001ZBgoogle.golang.org/genproto/googleapis/ads/googleads/v2/enums;enums\242\002\003GAA\252\002\035Google.Ads.GoogleAds.V2.Enums\312\002\035Google\\Ads\\GoogleAds\\V2\\Enums\352\002!Google::Ads::GoogleAds::V2::Enums'),
  serialized_pb=_b('\nBgoogle/ads/googleads_v2/proto/enums/travel_placeholder_field.proto\x12\x1dgoogle.ads.googleads.v2.enums\x1a\x1cgoogle/api/annotations.proto\"\xd6\x03\n\x1aTravelPlaceholderFieldEnum\"\xb7\x03\n\x16TravelPlaceholderField\x12\x0f\n\x0bUNSPECIFIED\x10\x00\x12\x0b\n\x07UNKNOWN\x10\x01\x12\x12\n\x0e\x44\x45STINATION_ID\x10\x02\x12\r\n\tORIGIN_ID\x10\x03\x12\t\n\x05TITLE\x10\x04\x12\x14\n\x10\x44\x45STINATION_NAME\x10\x05\x12\x0f\n\x0bORIGIN_NAME\x10\x06\x12\t\n\x05PRICE\x10\x07\x12\x13\n\x0f\x46ORMATTED_PRICE\x10\x08\x12\x0e\n\nSALE_PRICE\x10\t\x12\x18\n\x14\x46ORMATTED_SALE_PRICE\x10\n\x12\r\n\tIMAGE_URL\x10\x0b\x12\x0c\n\x08\x43\x41TEGORY\x10\x0c\x12\x17\n\x13\x43ONTEXTUAL_KEYWORDS\x10\r\x12\x17\n\x13\x44\x45STINATION_ADDRESS\x10\x0e\x12\r\n\tFINAL_URL\x10\x0f\x12\x15\n\x11\x46INAL_MOBILE_URLS\x10\x10\x12\x10\n\x0cTRACKING_URL\x10\x11\x12\x14\n\x10\x41NDROID_APP_LINK\x10\x12\x12\x1b\n\x17SIMILAR_DESTINATION_IDS\x10\x13\x12\x10\n\x0cIOS_APP_LINK\x10\x14\x12\x14\n\x10IOS_APP_STORE_ID\x10\x15\x42\xf0\x01\n!com.google.ads.googleads.v2.enumsB\x1bTravelPlaceholderFieldProtoP\x01ZBgoogle.golang.org/genproto/googleapis/ads/googleads/v2/enums;enums\xa2\x02\x03GAA\xaa\x02\x1dGoogle.Ads.GoogleAds.V2.Enums\xca\x02\x1dGoogle\\Ads\\GoogleAds\\V2\\Enums\xea\x02!Google::Ads::GoogleAds::V2::Enumsb\x06proto3')
  ,
  dependencies=[google_dot_api_dot_annotations__pb2.DESCRIPTOR,])



_TRAVELPLACEHOLDERFIELDENUM_TRAVELPLACEHOLDERFIELD = _descriptor.EnumDescriptor(
  name='TravelPlaceholderField',
  full_name='google.ads.googleads.v2.enums.TravelPlaceholderFieldEnum.TravelPlaceholderField',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='UNSPECIFIED', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='UNKNOWN', index=1, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='DESTINATION_ID', index=2, number=2,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ORIGIN_ID', index=3, number=3,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='TITLE', index=4, number=4,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='DESTINATION_NAME', index=5, number=5,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ORIGIN_NAME', index=6, number=6,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='PRICE', index=7, number=7,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='FORMATTED_PRICE', index=8, number=8,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='SALE_PRICE', index=9, number=9,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='FORMATTED_SALE_PRICE', index=10, number=10,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='IMAGE_URL', index=11, number=11,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='CATEGORY', index=12, number=12,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='CONTEXTUAL_KEYWORDS', index=13, number=13,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='DESTINATION_ADDRESS', index=14, number=14,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='FINAL_URL', index=15, number=15,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='FINAL_MOBILE_URLS', index=16, number=16,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='TRACKING_URL', index=17, number=17,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ANDROID_APP_LINK', index=18, number=18,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='SIMILAR_DESTINATION_IDS', index=19, number=19,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='IOS_APP_LINK', index=20, number=20,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='IOS_APP_STORE_ID', index=21, number=21,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=163,
  serialized_end=602,
)
_sym_db.RegisterEnumDescriptor(_TRAVELPLACEHOLDERFIELDENUM_TRAVELPLACEHOLDERFIELD)


_TRAVELPLACEHOLDERFIELDENUM = _descriptor.Descriptor(
  name='TravelPlaceholderFieldEnum',
  full_name='google.ads.googleads.v2.enums.TravelPlaceholderFieldEnum',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _TRAVELPLACEHOLDERFIELDENUM_TRAVELPLACEHOLDERFIELD,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=132,
  serialized_end=602,
)

_TRAVELPLACEHOLDERFIELDENUM_TRAVELPLACEHOLDERFIELD.containing_type = _TRAVELPLACEHOLDERFIELDENUM
DESCRIPTOR.message_types_by_name['TravelPlaceholderFieldEnum'] = _TRAVELPLACEHOLDERFIELDENUM
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

TravelPlaceholderFieldEnum = _reflection.GeneratedProtocolMessageType('TravelPlaceholderFieldEnum', (_message.Message,), dict(
  DESCRIPTOR = _TRAVELPLACEHOLDERFIELDENUM,
  __module__ = 'google.ads.googleads_v2.proto.enums.travel_placeholder_field_pb2'
  ,
  __doc__ = """Values for Travel placeholder fields. For more information about dynamic
  remarketing feeds, see
  https://support.google.com/google-ads/answer/6053288.
  """,
  # @@protoc_insertion_point(class_scope:google.ads.googleads.v2.enums.TravelPlaceholderFieldEnum)
  ))
_sym_db.RegisterMessage(TravelPlaceholderFieldEnum)


DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: google/ads/googleads_v2/proto/errors/feed_error.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='google/ads/googleads_v2/proto/errors/feed_error.proto',
  package='google.ads.googleads.v2.errors',
  syntax='proto3',
  serialized_options=_b('\n\"com.google.ads.googleads.v2.errorsB\016FeedErrorProtoP\001ZDgoogle.golang.org/genproto/googleapis/ads/googleads/v2/errors;errors\242\002\003GAA\252\002\036Google.Ads.GoogleAds.V2.Errors\312\002\036Google\\Ads\\GoogleAds\\V2\\Errors\352\002\"Google::Ads::GoogleAds::V2::Errors'),
  serialized_pb=_b('\n5google/ads/googleads_v2/proto/errors/feed_error.proto\x12\x1egoogle.ads.googleads.v2.errors\x1a\x1cgoogle/api/annotations.proto\"\xf9\x05\n\rFeedErrorEnum\"\xe7\x05\n\tFeedError\x12\x0f\n\x0bUNSPECIFIED\x10\x00\x12\x0b\n\x07UNKNOWN\x10\x01\x12\x1e\n\x1a\x41TTRIBUTE_NAMES_NOT_UNIQUE\x10\x02\x12/\n+ATTRIBUTES_DO_NOT_MATCH_EXISTING_ATTRIBUTES\x10\x03\x12.\n*CANNOT_SPECIFY_USER_ORIGIN_FOR_SYSTEM_FEED\x10\x04\x12\x34\n0CANNOT_SPECIFY_GOOGLE_ORIGIN_FOR_NON_SYSTEM_FEED\x10\x05\x12\x32\n.CANNOT_SPECIFY_FEED_ATTRIBUTES_FOR_SYSTEM_FEED\x10\x06\x12\x34\n0CANNOT_UPDATE_FEED_ATTRIBUTES_WITH_ORIGIN_GOOGLE\x10\x07\x12\x10\n\x0c\x46\x45\x45\x44_REMOVED\x10\x08\x12\x18\n\x14INVALID_ORIGIN_VALUE\x10\t\x12\x1b\n\x17\x46\x45\x45\x44_ORIGIN_IS_NOT_USER\x10\n\x12 \n\x1cINVALID_AUTH_TOKEN_FOR_EMAIL\x10\x0b\x12\x11\n\rINVALID_EMAIL\x10\x0c\x12\x17\n\x13\x44UPLICATE_FEED_NAME\x10\r\x12\x15\n\x11INVALID_FEED_NAME\x10\x0e\x12\x16\n\x12MISSING_OAUTH_INFO\x10\x0f\x12.\n*NEW_ATTRIBUTE_CANNOT_BE_PART_OF_UNIQUE_KEY\x10\x10\x12\x17\n\x13TOO_MANY_ATTRIBUTES\x10\x11\x12\x1c\n\x18INVALID_BUSINESS_ACCOUNT\x10\x12\x12\x33\n/BUSINESS_ACCOUNT_CANNOT_ACCESS_LOCATION_ACCOUNT\x10\x13\x12\x1e\n\x1aINVALID_AFFILIATE_CHAIN_ID\x10\x14\x12\x19\n\x15\x44UPLICATE_SYSTEM_FEED\x10\x15\x42\xe9\x01\n\"com.google.ads.googleads.v2.errorsB\x0e\x46\x65\x65\x64\x45rrorProtoP\x01ZDgoogle.golang.org/genproto/googleapis/ads/googleads/v2/errors;errors\xa2\x02\x03GAA\xaa\x02\x1eGoogle.Ads.GoogleAds.V2.Errors\xca\x02\x1eGoogle\\Ads\\GoogleAds\\V2\\Errors\xea\x02\"Google::Ads::GoogleAds::V2::Errorsb\x06proto3')
  ,
  dependencies=[google_dot_api_dot_annotations__pb2.DESCRIPTOR,])



_FEEDERRORENUM_FEEDERROR = _descriptor.EnumDescriptor(
  name='FeedError',
  full_name='google.ads.googleads.v2.errors.FeedErrorEnum.FeedError',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='UNSPECIFIED', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='UNKNOWN', index=1, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ATTRIBUTE_NAMES_NOT_UNIQUE', index=2, number=2,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ATTRIBUTES_DO_NOT_MATCH_EXISTING_ATTRIBUTES', index=3, number=3,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='CANNOT_SPECIFY_USER_ORIGIN_FOR_SYSTEM_FEED', index=4, number=4,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='CANNOT_SPECIFY_GOOGLE_ORIGIN_FOR_NON_SYSTEM_FEED', index=5, number=5,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='CANNOT_SPECIFY_FEED_ATTRIBUTES_FOR_SYSTEM_FEED', index=6, number=6,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='CANNOT_UPDATE_FEED_ATTRIBUTES_WITH_ORIGIN_GOOGLE', index=7, number=7,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='FEED_REMOVED', index=8, number=8,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='INVALID_ORIGIN_VALUE', index=9, number=9,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='FEED_ORIGIN_IS_NOT_USER', index=10, number=10,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='INVALID_AUTH_TOKEN_FOR_EMAIL', index=11, number=11,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='INVALID_EMAIL', index=12, number=12,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='DUPLICATE_FEED_NAME', index=13, number=13,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='INVALID_FEED_NAME', index=14, number=14,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='MISSING_OAUTH_INFO', index=15, number=15,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='NEW_ATTRIBUTE_CANNOT_BE_PART_OF_UNIQUE_KEY', index=16, number=16,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='TOO_MANY_ATTRIBUTES', index=17, number=17,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='INVALID_BUSINESS_ACCOUNT', index=18, number=18,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='BUSINESS_ACCOUNT_CANNOT_ACCESS_LOCATION_ACCOUNT', index=19, number=19,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='INVALID_AFFILIATE_CHAIN_ID', index=20, number=20,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='DUPLICATE_SYSTEM_FEED', index=21, number=21,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=138,
  serialized_end=881,
)
_sym_db.RegisterEnumDescriptor(_FEEDERRORENUM_FEEDERROR)


_FEEDERRORENUM = _descriptor.Descriptor(
  name='FeedErrorEnum',
  full_name='google.ads.googleads.v2.errors.FeedErrorEnum',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _FEEDERRORENUM_FEEDERROR,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=120,
  serialized_end=881,
)

_FEEDERRORENUM_FEEDERROR.containing_type = _FEEDERRORENUM
DESCRIPTOR.message_types_by_name['FeedErrorEnum'] = _FEEDERRORENUM
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

FeedErrorEnum = _reflection.GeneratedProtocolMessageType('FeedErrorEnum', (_message.Message,), dict(
  DESCRIPTOR = _FEEDERRORENUM,
  __module__ = 'google.ads.googleads_v2.proto.errors.feed_error_pb2'
  ,
  __doc__ = """Container for enum describing possible feed errors.
  """,
  # @@protoc_insertion_point(class_scope:google.ads.googleads.v2.errors.FeedErrorEnum)
  ))
_sym_db.RegisterMessage(FeedErrorEnum)


DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: google/ads/googleads_v2/proto/errors/authentication_error.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='google/ads/googleads_v2/proto/errors/authentication_error.proto',
  package='google.ads.googleads.v2.errors',
  syntax='proto3',
  serialized_options=_b('\n\"com.google.ads.googleads.v2.errorsB\030AuthenticationErrorProtoP\001ZDgoogle.golang.org/genproto/googleapis/ads/googleads/v2/errors;errors\242\002\003GAA\252\002\036Google.Ads.GoogleAds.V2.Errors\312\002\036Google\\Ads\\GoogleAds\\V2\\Errors\352\002\"Google::Ads::GoogleAds::V2::Errors'),
  serialized_pb=_b('\n?google/ads/googleads_v2/proto/errors/authentication_error.proto\x12\x1egoogle.ads.googleads.v2.errors\x1a\x1cgoogle/api/annotations.proto\"\xe8\x04\n\x17\x41uthenticationErrorEnum\"\xcc\x04\n\x13\x41uthenticationError\x12\x0f\n\x0bUNSPECIFIED\x10\x00\x12\x0b\n\x07UNKNOWN\x10\x01\x12\x18\n\x14\x41UTHENTICATION_ERROR\x10\x02\x12\x1e\n\x1a\x43LIENT_CUSTOMER_ID_INVALID\x10\x05\x12\x16\n\x12\x43USTOMER_NOT_FOUND\x10\x08\x12\x1a\n\x16GOOGLE_ACCOUNT_DELETED\x10\t\x12!\n\x1dGOOGLE_ACCOUNT_COOKIE_INVALID\x10\n\x12(\n$GOOGLE_ACCOUNT_AUTHENTICATION_FAILED\x10\x19\x12-\n)GOOGLE_ACCOUNT_USER_AND_ADS_USER_MISMATCH\x10\x0c\x12\x19\n\x15LOGIN_COOKIE_REQUIRED\x10\r\x12\x10\n\x0cNOT_ADS_USER\x10\x0e\x12\x17\n\x13OAUTH_TOKEN_INVALID\x10\x0f\x12\x17\n\x13OAUTH_TOKEN_EXPIRED\x10\x10\x12\x18\n\x14OAUTH_TOKEN_DISABLED\x10\x11\x12\x17\n\x13OAUTH_TOKEN_REVOKED\x10\x12\x12\x1e\n\x1aOAUTH_TOKEN_HEADER_INVALID\x10\x13\x12\x18\n\x14LOGIN_COOKIE_INVALID\x10\x14\x12\x13\n\x0fUSER_ID_INVALID\x10\x16\x12&\n\"TWO_STEP_VERIFICATION_NOT_ENROLLED\x10\x17\x12$\n ADVANCED_PROTECTION_NOT_ENROLLED\x10\x18\x42\xf3\x01\n\"com.google.ads.googleads.v2.errorsB\x18\x41uthenticationErrorProtoP\x01ZDgoogle.golang.org/genproto/googleapis/ads/googleads/v2/errors;errors\xa2\x02\x03GAA\xaa\x02\x1eGoogle.Ads.GoogleAds.V2.Errors\xca\x02\x1eGoogle\\Ads\\GoogleAds\\V2\\Errors\xea\x02\"Google::Ads::GoogleAds::V2::Errorsb\x06proto3')
  ,
  dependencies=[google_dot_api_dot_annotations__pb2.DESCRIPTOR,])



_AUTHENTICATIONERRORENUM_AUTHENTICATIONERROR = _descriptor.EnumDescriptor(
  name='AuthenticationError',
  full_name='google.ads.googleads.v2.errors.AuthenticationErrorEnum.AuthenticationError',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='UNSPECIFIED', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='UNKNOWN', index=1, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='AUTHENTICATION_ERROR', index=2, number=2,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='CLIENT_CUSTOMER_ID_INVALID', index=3, number=5,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='CUSTOMER_NOT_FOUND', index=4, number=8,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='GOOGLE_ACCOUNT_DELETED', index=5, number=9,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='GOOGLE_ACCOUNT_COOKIE_INVALID', index=6, number=10,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='GOOGLE_ACCOUNT_AUTHENTICATION_FAILED', index=7, number=25,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='GOOGLE_ACCOUNT_USER_AND_ADS_USER_MISMATCH', index=8, number=12,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='LOGIN_COOKIE_REQUIRED', index=9, number=13,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='NOT_ADS_USER', index=10, number=14,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='OAUTH_TOKEN_INVALID', index=11, number=15,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='OAUTH_TOKEN_EXPIRED', index=12, number=16,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='OAUTH_TOKEN_DISABLED', index=13, number=17,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='OAUTH_TOKEN_REVOKED', index=14, number=18,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='OAUTH_TOKEN_HEADER_INVALID', index=15, number=19,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='LOGIN_COOKIE_INVALID', index=16, number=20,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='USER_ID_INVALID', index=17, number=22,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='TWO_STEP_VERIFICATION_NOT_ENROLLED', index=18, number=23,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ADVANCED_PROTECTION_NOT_ENROLLED', index=19, number=24,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=158,
  serialized_end=746,
)
_sym_db.RegisterEnumDescriptor(_AUTHENTICATIONERRORENUM_AUTHENTICATIONERROR)


_AUTHENTICATIONERRORENUM = _descriptor.Descriptor(
  name='AuthenticationErrorEnum',
  full_name='google.ads.googleads.v2.errors.AuthenticationErrorEnum',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _AUTHENTICATIONERRORENUM_AUTHENTICATIONERROR,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=130,
  serialized_end=746,
)

_AUTHENTICATIONERRORENUM_AUTHENTICATIONERROR.containing_type = _AUTHENTICATIONERRORENUM
DESCRIPTOR.message_types_by_name['AuthenticationErrorEnum'] = _AUTHENTICATIONERRORENUM
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

AuthenticationErrorEnum = _reflection.GeneratedProtocolMessageType('AuthenticationErrorEnum', (_message.Message,), dict(
  DESCRIPTOR = _AUTHENTICATIONERRORENUM,
  __module__ = 'google.ads.googleads_v2.proto.errors.authentication_error_pb2'
  ,
  __doc__ = """Container for enum describing possible authentication errors.
  """,
  # @@protoc_insertion_point(class_scope:google.ads.googleads.v2.errors.AuthenticationErrorEnum)
  ))
_sym_db.RegisterMessage(AuthenticationErrorEnum)


DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: google/ads/googleads_v1/proto/common/custom_parameter.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2
from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='google/ads/googleads_v1/proto/common/custom_parameter.proto',
  package='google.ads.googleads.v1.common',
  syntax='proto3',
  serialized_options=_b('\n\"com.google.ads.googleads.v1.commonB\024CustomParameterProtoP\001ZDgoogle.golang.org/genproto/googleapis/ads/googleads/v1/common;common\242\002\003GAA\252\002\036Google.Ads.GoogleAds.V1.Common\312\002\036Google\\Ads\\GoogleAds\\V1\\Common\352\002\"Google::Ads::GoogleAds::V1::Common'),
  serialized_pb=_b('\n;google/ads/googleads_v1/proto/common/custom_parameter.proto\x12\x1egoogle.ads.googleads.v1.common\x1a\x1egoogle/protobuf/wrappers.proto\x1a\x1cgoogle/api/annotations.proto\"i\n\x0f\x43ustomParameter\x12)\n\x03key\x18\x01 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12+\n\x05value\x18\x02 \x01(\x0b\x32\x1c.google.protobuf.StringValueB\xef\x01\n\"com.google.ads.googleads.v1.commonB\x14\x43ustomParameterProtoP\x01ZDgoogle.golang.org/genproto/googleapis/ads/googleads/v1/common;common\xa2\x02\x03GAA\xaa\x02\x1eGoogle.Ads.GoogleAds.V1.Common\xca\x02\x1eGoogle\\Ads\\GoogleAds\\V1\\Common\xea\x02\"Google::Ads::GoogleAds::V1::Commonb\x06proto3')
  ,
  dependencies=[google_dot_protobuf_dot_wrappers__pb2.DESCRIPTOR,google_dot_api_dot_annotations__pb2.DESCRIPTOR,])




_CUSTOMPARAMETER = _descriptor.Descriptor(
  name='CustomParameter',
  full_name='google.ads.googleads.v1.common.CustomParameter',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='google.ads.googleads.v1.common.CustomParameter.key', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='value', full_name='google.ads.googleads.v1.common.CustomParameter.value', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=157,
  serialized_end=262,
)

_CUSTOMPARAMETER.fields_by_name['key'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
_CUSTOMPARAMETER.fields_by_name['value'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
DESCRIPTOR.message_types_by_name['CustomParameter'] = _CUSTOMPARAMETER
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

CustomParameter = _reflection.GeneratedProtocolMessageType('CustomParameter', (_message.Message,), dict(
  DESCRIPTOR = _CUSTOMPARAMETER,
  __module__ = 'google.ads.googleads_v1.proto.common.custom_parameter_pb2'
  ,
  __doc__ = """A mapping that can be used by custom parameter tags in a
  ``tracking_url_template``, ``final_urls``, or ``mobile_final_urls``.
  
  
  Attributes:
      key:
          The key matching the parameter tag name.
      value:
          The value to be substituted.
  """,
  # @@protoc_insertion_point(class_scope:google.ads.googleads.v1.common.CustomParameter)
  ))
_sym_db.RegisterMessage(CustomParameter)


DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: google/ads/googleads_v2/proto/resources/keyword_plan.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.ads.google_ads.v2.proto.common import dates_pb2 as google_dot_ads_dot_googleads__v2_dot_proto_dot_common_dot_dates__pb2
from google.ads.google_ads.v2.proto.enums import keyword_plan_forecast_interval_pb2 as google_dot_ads_dot_googleads__v2_dot_proto_dot_enums_dot_keyword__plan__forecast__interval__pb2
from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2
from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='google/ads/googleads_v2/proto/resources/keyword_plan.proto',
  package='google.ads.googleads.v2.resources',
  syntax='proto3',
  serialized_options=_b('\n%com.google.ads.googleads.v2.resourcesB\020KeywordPlanProtoP\001ZJgoogle.golang.org/genproto/googleapis/ads/googleads/v2/resources;resources\242\002\003GAA\252\002!Google.Ads.GoogleAds.V2.Resources\312\002!Google\\Ads\\GoogleAds\\V2\\Resources\352\002%Google::Ads::GoogleAds::V2::Resources'),
  serialized_pb=_b('\n:google/ads/googleads_v2/proto/resources/keyword_plan.proto\x12!google.ads.googleads.v2.resources\x1a\x30google/ads/googleads_v2/proto/common/dates.proto\x1aHgoogle/ads/googleads_v2/proto/enums/keyword_plan_forecast_interval.proto\x1a\x1egoogle/protobuf/wrappers.proto\x1a\x1cgoogle/api/annotations.proto\"\xd0\x01\n\x0bKeywordPlan\x12\x15\n\rresource_name\x18\x01 \x01(\t\x12\'\n\x02id\x18\x02 \x01(\x0b\x32\x1b.google.protobuf.Int64Value\x12*\n\x04name\x18\x03 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12U\n\x0f\x66orecast_period\x18\x04 \x01(\x0b\x32<.google.ads.googleads.v2.resources.KeywordPlanForecastPeriod\"\xdd\x01\n\x19KeywordPlanForecastPeriod\x12s\n\rdate_interval\x18\x01 \x01(\x0e\x32Z.google.ads.googleads.v2.enums.KeywordPlanForecastIntervalEnum.KeywordPlanForecastIntervalH\x00\x12?\n\ndate_range\x18\x02 \x01(\x0b\x32).google.ads.googleads.v2.common.DateRangeH\x00\x42\n\n\x08intervalB\xfd\x01\n%com.google.ads.googleads.v2.resourcesB\x10KeywordPlanProtoP\x01ZJgoogle.golang.org/genproto/googleapis/ads/googleads/v2/resources;resources\xa2\x02\x03GAA\xaa\x02!Google.Ads.GoogleAds.V2.Resources\xca\x02!Google\\Ads\\GoogleAds\\V2\\Resources\xea\x02%Google::Ads::GoogleAds::V2::Resourcesb\x06proto3')
  ,
  dependencies=[google_dot_ads_dot_googleads__v2_dot_proto_dot_common_dot_dates__pb2.DESCRIPTOR,google_dot_ads_dot_googleads__v2_dot_proto_dot_enums_dot_keyword__plan__forecast__interval__pb2.DESCRIPTOR,google_dot_protobuf_dot_wrappers__pb2.DESCRIPTOR,google_dot_api_dot_annotations__pb2.DESCRIPTOR,])




_KEYWORDPLAN = _descriptor.Descriptor(
  name='KeywordPlan',
  full_name='google.ads.googleads.v2.resources.KeywordPlan',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='resource_name', full_name='google.ads.googleads.v2.resources.KeywordPlan.resource_name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='id', full_name='google.ads.googleads.v2.resources.KeywordPlan.id', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='name', full_name='google.ads.googleads.v2.resources.KeywordPlan.name', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='forecast_period', full_name='google.ads.googleads.v2.resources.KeywordPlan.forecast_period', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=284,
  serialized_end=492,
)


_KEYWORDPLANFORECASTPERIOD = _descriptor.Descriptor(
  name='KeywordPlanForecastPeriod',
  full_name='google.ads.googleads.v2.resources.KeywordPlanForecastPeriod',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='date_interval', full_name='google.ads.googleads.v2.resources.KeywordPlanForecastPeriod.date_interval', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='date_range', full_name='google.ads.googleads.v2.resources.KeywordPlanForecastPeriod.date_range', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='interval', full_name='google.ads.googleads.v2.resources.KeywordPlanForecastPeriod.interval',
      index=0, containing_type=None, fields=[]),
  ],
  serialized_start=495,
  serialized_end=716,
)

_KEYWORDPLAN.fields_by_name['id'].message_type = google_dot_protobuf_dot_wrappers__pb2._INT64VALUE
_KEYWORDPLAN.fields_by_name['name'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
_KEYWORDPLAN.fields_by_name['forecast_period'].message_type = _KEYWORDPLANFORECASTPERIOD
_KEYWORDPLANFORECASTPERIOD.fields_by_name['date_interval'].enum_type = google_dot_ads_dot_googleads__v2_dot_proto_dot_enums_dot_keyword__plan__forecast__interval__pb2._KEYWORDPLANFORECASTINTERVALENUM_KEYWORDPLANFORECASTINTERVAL
_KEYWORDPLANFORECASTPERIOD.fields_by_name['date_range'].message_type = google_dot_ads_dot_googleads__v2_dot_proto_dot_common_dot_dates__pb2._DATERANGE
_KEYWORDPLANFORECASTPERIOD.oneofs_by_name['interval'].fields.append(
  _KEYWORDPLANFORECASTPERIOD.fields_by_name['date_interval'])
_KEYWORDPLANFORECASTPERIOD.fields_by_name['date_interval'].containing_oneof = _KEYWORDPLANFORECASTPERIOD.oneofs_by_name['interval']
_KEYWORDPLANFORECASTPERIOD.oneofs_by_name['interval'].fields.append(
  _KEYWORDPLANFORECASTPERIOD.fields_by_name['date_range'])
_KEYWORDPLANFORECASTPERIOD.fields_by_name['date_range'].containing_oneof = _KEYWORDPLANFORECASTPERIOD.oneofs_by_name['interval']
DESCRIPTOR.message_types_by_name['KeywordPlan'] = _KEYWORDPLAN
DESCRIPTOR.message_types_by_name['KeywordPlanForecastPeriod'] = _KEYWORDPLANFORECASTPERIOD
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

KeywordPlan = _reflection.GeneratedProtocolMessageType('KeywordPlan', (_message.Message,), dict(
  DESCRIPTOR = _KEYWORDPLAN,
  __module__ = 'google.ads.googleads_v2.proto.resources.keyword_plan_pb2'
  ,
  __doc__ = """A Keyword Planner plan. Max number of saved keyword plans: 10000. It's
  possible to remove plans if limit is reached.
  
  
  Attributes:
      resource_name:
          The resource name of the Keyword Planner plan. KeywordPlan
          resource names have the form:
          ``customers/{customer_id}/keywordPlans/{kp_plan_id}``
      id:
          The ID of the keyword plan.
      name:
          The name of the keyword plan.  This field is required and
          should not be empty when creating new keyword plans.
      forecast_period:
          The date period used for forecasting the plan.
  """,
  # @@protoc_insertion_point(class_scope:google.ads.googleads.v2.resources.KeywordPlan)
  ))
_sym_db.RegisterMessage(KeywordPlan)

KeywordPlanForecastPeriod = _reflection.GeneratedProtocolMessageType('KeywordPlanForecastPeriod', (_message.Message,), dict(
  DESCRIPTOR = _KEYWORDPLANFORECASTPERIOD,
  __module__ = 'google.ads.googleads_v2.proto.resources.keyword_plan_pb2'
  ,
  __doc__ = """The forecasting period associated with the keyword plan.
  
  
  Attributes:
      interval:
          Required. The date used for forecasting the Plan.
      date_interval:
          A future date range relative to the current date used for
          forecasting.
      date_range:
          The custom date range used for forecasting. The start and end
          dates must be in the future. Otherwise, an error will be
          returned when the forecasting action is performed. The start
          and end dates are inclusive.
  """,
  # @@protoc_insertion_point(class_scope:google.ads.googleads.v2.resources.KeywordPlanForecastPeriod)
  ))
_sym_db.RegisterMessage(KeywordPlanForecastPeriod)


DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: google/ads/googleads_v2/proto/errors/campaign_criterion_error.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='google/ads/googleads_v2/proto/errors/campaign_criterion_error.proto',
  package='google.ads.googleads.v2.errors',
  syntax='proto3',
  serialized_options=_b('\n\"com.google.ads.googleads.v2.errorsB\033CampaignCriterionErrorProtoP\001ZDgoogle.golang.org/genproto/googleapis/ads/googleads/v2/errors;errors\242\002\003GAA\252\002\036Google.Ads.GoogleAds.V2.Errors\312\002\036Google\\Ads\\GoogleAds\\V2\\Errors\352\002\"Google::Ads::GoogleAds::V2::Errors'),
  serialized_pb=_b('\nCgoogle/ads/googleads_v2/proto/errors/campaign_criterion_error.proto\x12\x1egoogle.ads.googleads.v2.errors\x1a\x1cgoogle/api/annotations.proto\"\xf5\x03\n\x1a\x43\x61mpaignCriterionErrorEnum\"\xd6\x03\n\x16\x43\x61mpaignCriterionError\x12\x0f\n\x0bUNSPECIFIED\x10\x00\x12\x0b\n\x07UNKNOWN\x10\x01\x12\x1a\n\x16\x43ONCRETE_TYPE_REQUIRED\x10\x02\x12\x19\n\x15INVALID_PLACEMENT_URL\x10\x03\x12 \n\x1c\x43\x41NNOT_EXCLUDE_CRITERIA_TYPE\x10\x04\x12\'\n#CANNOT_SET_STATUS_FOR_CRITERIA_TYPE\x10\x05\x12+\n\'CANNOT_SET_STATUS_FOR_EXCLUDED_CRITERIA\x10\x06\x12\x1d\n\x19\x43\x41NNOT_TARGET_AND_EXCLUDE\x10\x07\x12\x17\n\x13TOO_MANY_OPERATIONS\x10\x08\x12-\n)OPERATOR_NOT_SUPPORTED_FOR_CRITERION_TYPE\x10\t\x12\x43\n?SHOPPING_CAMPAIGN_SALES_COUNTRY_NOT_SUPPORTED_FOR_SALES_CHANNEL\x10\n\x12\x1d\n\x19\x43\x41NNOT_ADD_EXISTING_FIELD\x10\x0b\x12$\n CANNOT_UPDATE_NEGATIVE_CRITERION\x10\x0c\x42\xf6\x01\n\"com.google.ads.googleads.v2.errorsB\x1b\x43\x61mpaignCriterionErrorProtoP\x01ZDgoogle.golang.org/genproto/googleapis/ads/googleads/v2/errors;errors\xa2\x02\x03GAA\xaa\x02\x1eGoogle.Ads.GoogleAds.V2.Errors\xca\x02\x1eGoogle\\Ads\\GoogleAds\\V2\\Errors\xea\x02\"Google::Ads::GoogleAds::V2::Errorsb\x06proto3')
  ,
  dependencies=[google_dot_api_dot_annotations__pb2.DESCRIPTOR,])



_CAMPAIGNCRITERIONERRORENUM_CAMPAIGNCRITERIONERROR = _descriptor.EnumDescriptor(
  name='CampaignCriterionError',
  full_name='google.ads.googleads.v2.errors.CampaignCriterionErrorEnum.CampaignCriterionError',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='UNSPECIFIED', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='UNKNOWN', index=1, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='CONCRETE_TYPE_REQUIRED', index=2, number=2,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='INVALID_PLACEMENT_URL', index=3, number=3,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='CANNOT_EXCLUDE_CRITERIA_TYPE', index=4, number=4,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='CANNOT_SET_STATUS_FOR_CRITERIA_TYPE', index=5, number=5,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='CANNOT_SET_STATUS_FOR_EXCLUDED_CRITERIA', index=6, number=6,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='CANNOT_TARGET_AND_EXCLUDE', index=7, number=7,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='TOO_MANY_OPERATIONS', index=8, number=8,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='OPERATOR_NOT_SUPPORTED_FOR_CRITERION_TYPE', index=9, number=9,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='SHOPPING_CAMPAIGN_SALES_COUNTRY_NOT_SUPPORTED_FOR_SALES_CHANNEL', index=10, number=10,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='CANNOT_ADD_EXISTING_FIELD', index=11, number=11,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='CANNOT_UPDATE_NEGATIVE_CRITERION', index=12, number=12,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=165,
  serialized_end=635,
)
_sym_db.RegisterEnumDescriptor(_CAMPAIGNCRITERIONERRORENUM_CAMPAIGNCRITERIONERROR)


_CAMPAIGNCRITERIONERRORENUM = _descriptor.Descriptor(
  name='CampaignCriterionErrorEnum',
  full_name='google.ads.googleads.v2.errors.CampaignCriterionErrorEnum',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _CAMPAIGNCRITERIONERRORENUM_CAMPAIGNCRITERIONERROR,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=134,
  serialized_end=635,
)

_CAMPAIGNCRITERIONERRORENUM_CAMPAIGNCRITERIONERROR.containing_type = _CAMPAIGNCRITERIONERRORENUM
DESCRIPTOR.message_types_by_name['CampaignCriterionErrorEnum'] = _CAMPAIGNCRITERIONERRORENUM
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

CampaignCriterionErrorEnum = _reflection.GeneratedProtocolMessageType('CampaignCriterionErrorEnum', (_message.Message,), dict(
  DESCRIPTOR = _CAMPAIGNCRITERIONERRORENUM,
  __module__ = 'google.ads.googleads_v2.proto.errors.campaign_criterion_error_pb2'
  ,
  __doc__ = """Container for enum describing possible campaign criterion errors.
  """,
  # @@protoc_insertion_point(class_scope:google.ads.googleads.v2.errors.CampaignCriterionErrorEnum)
  ))
_sym_db.RegisterMessage(CampaignCriterionErrorEnum)


DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: google/ads/googleads_v2/proto/enums/feed_item_quality_disapproval_reason.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='google/ads/googleads_v2/proto/enums/feed_item_quality_disapproval_reason.proto',
  package='google.ads.googleads.v2.enums',
  syntax='proto3',
  serialized_options=_b('\n!com.google.ads.googleads.v2.enumsB%FeedItemQualityDisapprovalReasonProtoP\001ZBgoogle.golang.org/genproto/googleapis/ads/googleads/v2/enums;enums\242\002\003GAA\252\002\035Google.Ads.GoogleAds.V2.Enums\312\002\035Google\\Ads\\GoogleAds\\V2\\Enums\352\002!Google::Ads::GoogleAds::V2::Enums'),
  serialized_pb=_b('\nNgoogle/ads/googleads_v2/proto/enums/feed_item_quality_disapproval_reason.proto\x12\x1dgoogle.ads.googleads.v2.enums\x1a\x1cgoogle/api/annotations.proto\"\xe0\x06\n$FeedItemQualityDisapprovalReasonEnum\"\xb7\x06\n FeedItemQualityDisapprovalReason\x12\x0f\n\x0bUNSPECIFIED\x10\x00\x12\x0b\n\x07UNKNOWN\x10\x01\x12\"\n\x1ePRICE_TABLE_REPETITIVE_HEADERS\x10\x02\x12&\n\"PRICE_TABLE_REPETITIVE_DESCRIPTION\x10\x03\x12!\n\x1dPRICE_TABLE_INCONSISTENT_ROWS\x10\x04\x12*\n&PRICE_DESCRIPTION_HAS_PRICE_QUALIFIERS\x10\x05\x12\x1e\n\x1aPRICE_UNSUPPORTED_LANGUAGE\x10\x06\x12.\n*PRICE_TABLE_ROW_HEADER_TABLE_TYPE_MISMATCH\x10\x07\x12/\n+PRICE_TABLE_ROW_HEADER_HAS_PROMOTIONAL_TEXT\x10\x08\x12,\n(PRICE_TABLE_ROW_DESCRIPTION_NOT_RELEVANT\x10\t\x12\x34\n0PRICE_TABLE_ROW_DESCRIPTION_HAS_PROMOTIONAL_TEXT\x10\n\x12\x31\n-PRICE_TABLE_ROW_HEADER_DESCRIPTION_REPETITIVE\x10\x0b\x12\x1e\n\x1aPRICE_TABLE_ROW_UNRATEABLE\x10\x0c\x12!\n\x1dPRICE_TABLE_ROW_PRICE_INVALID\x10\r\x12\x1f\n\x1bPRICE_TABLE_ROW_URL_INVALID\x10\x0e\x12)\n%PRICE_HEADER_OR_DESCRIPTION_HAS_PRICE\x10\x0f\x12.\n*STRUCTURED_SNIPPETS_HEADER_POLICY_VIOLATED\x10\x10\x12\'\n#STRUCTURED_SNIPPETS_REPEATED_VALUES\x10\x11\x12,\n(STRUCTURED_SNIPPETS_EDITORIAL_GUIDELINES\x10\x12\x12,\n(STRUCTURED_SNIPPETS_HAS_PROMOTIONAL_TEXT\x10\x13\x42\xfa\x01\n!com.google.ads.googleads.v2.enumsB%FeedItemQualityDisapprovalReasonProtoP\x01ZBgoogle.golang.org/genproto/googleapis/ads/googleads/v2/enums;enums\xa2\x02\x03GAA\xaa\x02\x1dGoogle.Ads.GoogleAds.V2.Enums\xca\x02\x1dGoogle\\Ads\\GoogleAds\\V2\\Enums\xea\x02!Google::Ads::GoogleAds::V2::Enumsb\x06proto3')
  ,
  dependencies=[google_dot_api_dot_annotations__pb2.DESCRIPTOR,])



_FEEDITEMQUALITYDISAPPROVALREASONENUM_FEEDITEMQUALITYDISAPPROVALREASON = _descriptor.EnumDescriptor(
  name='FeedItemQualityDisapprovalReason',
  full_name='google.ads.googleads.v2.enums.FeedItemQualityDisapprovalReasonEnum.FeedItemQualityDisapprovalReason',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='UNSPECIFIED', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='UNKNOWN', index=1, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='PRICE_TABLE_REPETITIVE_HEADERS', index=2, number=2,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='PRICE_TABLE_REPETITIVE_DESCRIPTION', index=3, number=3,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='PRICE_TABLE_INCONSISTENT_ROWS', index=4, number=4,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='PRICE_DESCRIPTION_HAS_PRICE_QUALIFIERS', index=5, number=5,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='PRICE_UNSUPPORTED_LANGUAGE', index=6, number=6,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='PRICE_TABLE_ROW_HEADER_TABLE_TYPE_MISMATCH', index=7, number=7,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='PRICE_TABLE_ROW_HEADER_HAS_PROMOTIONAL_TEXT', index=8, number=8,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='PRICE_TABLE_ROW_DESCRIPTION_NOT_RELEVANT', index=9, number=9,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='PRICE_TABLE_ROW_DESCRIPTION_HAS_PROMOTIONAL_TEXT', index=10, number=10,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='PRICE_TABLE_ROW_HEADER_DESCRIPTION_REPETITIVE', index=11, number=11,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='PRICE_TABLE_ROW_UNRATEABLE', index=12, number=12,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='PRICE_TABLE_ROW_PRICE_INVALID', index=13, number=13,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='PRICE_TABLE_ROW_URL_INVALID', index=14, number=14,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='PRICE_HEADER_OR_DESCRIPTION_HAS_PRICE', index=15, number=15,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='STRUCTURED_SNIPPETS_HEADER_POLICY_VIOLATED', index=16, number=16,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='STRUCTURED_SNIPPETS_REPEATED_VALUES', index=17, number=17,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='STRUCTURED_SNIPPETS_EDITORIAL_GUIDELINES', index=18, number=18,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='STRUCTURED_SNIPPETS_HAS_PROMOTIONAL_TEXT', index=19, number=19,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=185,
  serialized_end=1008,
)
_sym_db.RegisterEnumDescriptor(_FEEDITEMQUALITYDISAPPROVALREASONENUM_FEEDITEMQUALITYDISAPPROVALREASON)


_FEEDITEMQUALITYDISAPPROVALREASONENUM = _descriptor.Descriptor(
  name='FeedItemQualityDisapprovalReasonEnum',
  full_name='google.ads.googleads.v2.enums.FeedItemQualityDisapprovalReasonEnum',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _FEEDITEMQUALITYDISAPPROVALREASONENUM_FEEDITEMQUALITYDISAPPROVALREASON,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=144,
  serialized_end=1008,
)

_FEEDITEMQUALITYDISAPPROVALREASONENUM_FEEDITEMQUALITYDISAPPROVALREASON.containing_type = _FEEDITEMQUALITYDISAPPROVALREASONENUM
DESCRIPTOR.message_types_by_name['FeedItemQualityDisapprovalReasonEnum'] = _FEEDITEMQUALITYDISAPPROVALREASONENUM
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

FeedItemQualityDisapprovalReasonEnum = _reflection.GeneratedProtocolMessageType('FeedItemQualityDisapprovalReasonEnum', (_message.Message,), dict(
  DESCRIPTOR = _FEEDITEMQUALITYDISAPPROVALREASONENUM,
  __module__ = 'google.ads.googleads_v2.proto.enums.feed_item_quality_disapproval_reason_pb2'
  ,
  __doc__ = """Container for enum describing possible quality evaluation disapproval
  reasons of a feed item.
  """,
  # @@protoc_insertion_point(class_scope:google.ads.googleads.v2.enums.FeedItemQualityDisapprovalReasonEnum)
  ))
_sym_db.RegisterMessage(FeedItemQualityDisapprovalReasonEnum)


DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)
